asyncpokepy
===========

.. image:: https://img.shields.io/pypi/v/asyncpokepy.svg
    :target: https://pypi.python.org/pypi/asyncpokepy
    :alt: Latest PyPI version

An asynchronous Python API wrapper for the PokeAPI

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`asyncpokepy` was written by `Raj Sharma <yrsharma@icloud.com>`_.
